;********************************;
; PARADOX Script: LookUp         ;
;                                ;
; RptCheck, Version 1.1          ;
; 10 Jan 92                      ;
; Informant Communications Group ;
;                                ;
; Required scripts:              ;
;   GetRptCk                     ;
;   RptSet                       ;
;   GetRpt                       ;
;   LookUp                       ;
;********************************;

CREATELIB "LookUp"

;**************************************************;
; LookUpTab() provides a "lookup" of tables in the ;
; current directory; it calls TabLkUpScr() to open ;
; a window then displays the list of tables and    ;
; manages user input.                              ;
;**************************************************;
PROC LookUpTab()
  PRIVATE c,CurrRec,LineCount,CurrLine,NextLine,
          TopRec,RecCount,TotalRecs

  CURSOR OFF
  DO_IT!
  IF NOT ISTABLE("List")
    THEN MESSAGE "Creating list of tables..."
         CANVAS OFF
         MENU {Tools} {Info} {Inventory}
              {Tables} ENTER
         MOVETO [Name]
         EDITKEY
         ;
         ; delete "List" table from list
         ;
         LOCATE "List"
         DEL
         DO_IT!
    ELSE CANVAS OFF
         VIEW "List"
  ENDIF
  HOME
  ;
  ; initialize variables
  ;
  CurrRec  =1
  LineCount=1
  CurrLine =1
  NextLine =2
  TopRec   =1
  RecCount =0
  TotalRecs=NRECORDS("List")
  ;
  ; open window
  ;
  TabLkUpScr()

  WHILE True
    RecCount=TopRec
    MOVETO RECORD TopRec
    STYLE ATTRIBUTE 32
    @10,0
    ;
    ; write table names and file dates
    ; to the window
    ;
    WHILE RecCount<=TotalRecs AND LineCount<9
      ?"  "+FORMAT("w16,al",[Name])+
       STRVAL([Date])+"  "
      RecCount=RecCount+1
      LineCount=LineCount+1
      DOWN
    ENDWHILE
    ;
    ; if more than one screen (8 records), display
    ; markers indicating scroll directions
    ;
    IF TotalRecs>8
      THEN IF TopRec>1
             THEN @11,11 ??CHR(30)
           ENDIF
           IF LineCount=9
             THEN IF RecCount<=TotalRecs
                    THEN @18,11 ??CHR(31)
                  ENDIF
             ELSE @LineCount+9,12
           ENDIF
    ENDIF
    ;
    ; if less than one full screen, clear remaining
    ; display of unwanted lines
    ;
    WHILE LineCount<9
      ?SPACES(28)
      LineCount=LineCount+1
    ENDWHILE
    LineCount=1
    ;
    ; highlight current selection
    ;
    WHILE True
      PAINTCANVAS ATTRIBUTE 112
        CurrLine+10,12,CurrLine+10,37
      CANVAS ON
      ;
      ; get user input
      ;
      c=GETCHAR()
      SWITCH
        CASE c=-80:                     ;Down
          IF CurrRec<TotalRecs
            THEN CurrRec=CurrRec+1
                 NextLine=CurrLine+1
            ELSE BEEP
                 LOOP
          ENDIF
        CASE c=-72:                     ;Up
          IF CurrRec>1
            THEN CurrRec=CurrRec-1
                 NextLine=CurrLine-1
            ELSE BEEP
                 LOOP
          ENDIF
        CASE c=-81:                     ;PgDn
          IF TotalRecs>TopRec+7
            THEN TopRec=TopRec+7
            ELSE BEEP
                 LOOP
          ENDIF
          CurrRec=TopRec
          CurrLine=1
          QUITLOOP
        CASE c=-73:                     ;PgUp
          IF TopRec>8
            THEN TopRec=TopRec-7
            ELSE IF TopRec=1
                   THEN BEEP
                        LOOP
                   ELSE TopRec=1
                 ENDIF
          ENDIF
          CurrRec=TopRec
          CurrLine=1
          QUITLOOP
        CASE c=-71:                     ;Home
          IF TopRec>1
            THEN TopRec=1
            ELSE BEEP
                 LOOP
          ENDIF
          CurrRec=TopRec
          CurrLine=1
          QUITLOOP
        CASE c=-79:                     ;End
          IF TopRec<TotalRecs-7
            THEN TopRec=TotalRecs-7
            ELSE BEEP
                 LOOP
          ENDIF
          CurrRec=TotalRecs
          CurrLine=TotalRecs-TopRec+1
          QUITLOOP
        CASE c=13:                      ;Enter
          SETMARGIN OFF
          MOVETO RECORD CurrRec
          Names[1]=[Name]
          CLEARIMAGE
          RETURN
        CASE c=-59:                     ;F1
          MOVETO RECORD CurrRec
          GetRptDscpt([Name])
          CANVAS OFF
          ;
          ; clear List table from workspace
          ; before copying to canvas
          ;
          CLEARIMAGE
          ECHO NORMAL
          ECHO OFF
          ;
          ; place List table back on workspace
          ;
          VIEW "List"
          RptNameScr()
          TabLkUpScr()
          QUITLOOP
        CASE c=27:                      ;Esc
          ;
          ; clear List table from workspace
          ; and return with no change
          ;
          SETMARGIN OFF
          CLEARIMAGE
          RETURN
        OTHERWISE:
          BEEP
          LOOP
      ENDSWITCH
      IF NextLine<1
        THEN TopRec=TopRec-1
             CurrLine=1
             QUITLOOP
        ELSE IF NextLine>8
               THEN TopRec=TopRec+1
                    CurrLine=8
                    QUITLOOP
             ENDIF
      ENDIF
      CANVAS OFF
      ;
      ; clear highlight
      ;
      PAINTCANVAS
        ATTRIBUTE 32
        CurrLine+10,12,CurrLine+10,37
      CurrLine=NextLine
    ENDWHILE
    CANVAS OFF
  ENDWHILE
ENDPROC


;******************************************;
; TabLkUpScr() is called by LookUpTab() to ;
; open the window used to list the tables  ;
; available in the current directory.      ;
;******************************************;
PROC TabLkUpScr()
  ;
  ; paint shadow
  ;
  PAINTCANVAS
    ATTRIBUTE 8
    11,11,22,40

  STYLE ATTRIBUTE 32
  @10,10
  SETMARGIN 10

TEXT
AVAILABLE TABLESĿ
                            
                            
                            
                            
                            
                            
                            
                            
Ĵ
 [F1] Rpts     [Esc] Cancel 

ENDTEXT

  SETMARGIN 11
ENDPROC


;************************************************;
; LookUpPntr() is called from ChangeRptSet() and ;
; lists the printer setups currently available   ;
; from Custom Configuration.                     ;
;************************************************;
PROC LookUpPntr()
  PRIVATE c,Line,Next

  Line=1
  Next=1

  CANVAS OFF
  CURSOR OFF
  ;
  ; paint shadow
  ;
  PAINTCANVAS
    ATTRIBUTE 8
    5,51,19,76

  STYLE ATTRIBUTE 79
  @4,50
  SETMARGIN 50

TEXT
PRINTERSĿ
  StandardPrinter       
  Small-IBMgraphics     
  Reg-IBMgraphics       
  Small-Epson-MX/FX     
  Small-Oki-92/93       
  Small-Oki-82/83       
  Small-Oki-192         
  HPLaserJet            
  HP-Portrait-66lines   
  HP-Landscape-Normal   
  HP-LandscpCompressed  
  Intl-IBMcompatible    
  Intl-IBMcondensed     

ENDTEXT

  SETMARGIN 0
  ;
  ; identify default printer; DfltPntr is
  ; set in GetCurrSet()
  ;
  @4+DfltPntr,52+LEN(Pntr[DfltPntr]) ??"*"

  WHILE True
    ;
    ; highlight current selection
    ;
    PAINTCANVAS
      ATTRIBUTE 116
      4+Line,52,4+Line,73
    CANVAS ON
    ;
    ; get user input
    ;
    c=GETCHAR()

    SWITCH
      CASE c=-72:                       ;Up
        IF Line=1
          THEN BEEP
               LOOP
          ELSE NEXT=NEXT-1
        ENDIF
      CASE c=-80:                       ;Down
        IF Line=13
          THEN BEEP
               LOOP
          ELSE Next=Next+1
        ENDIF
      CASE c=13:                        ;Enter
        ;
        ; return selection
        ;
        RETURN Line
      CASE c=27:                        ;Esc
        ;
        ; return no selection
        ;
        RETURN 0
      OTHERWISE:
        BEEP
        LOOP
    ENDSWITCH
    CANVAS OFF
    ;
    ; clear highlight
    ;
    PAINTCANVAS
      ATTRIBUTE 79
      4+Line,52,4+Line,73
    Line=Next
  ENDWHILE
ENDPROC


;************************************************;
; LookUpPort() is called from ChangeRptSet() and ;
; lists the currently available printer ports.   ;
;************************************************;
PROC LookUpPort()
  PRIVATE c,Line,Next

  Line=1
  Next=1

  CANVAS OFF
  CURSOR OFF
  ;
  ; paint shadow
  ;
  PAINTCANVAS
    ATTRIBUTE 8
    9,51,16,60

  STYLE ATTRIBUTE 79
  @8,50
  SETMARGIN 50

TEXT
PORTSĿ
  LPT1  
  LPT2  
  LPT3  
  COM1  
  COM2  
  AUX   

ENDTEXT

  SETMARGIN 0

  WHILE True
    ;
    ; highlight current selection
    ;
    PAINTCANVAS
      ATTRIBUTE 116
      8+Line,52,8+Line,57
    CANVAS ON
    ;
    ; get user input
    ;
    c=GETCHAR()
    SWITCH
      CASE c=-72:                       ;Up
        IF Line=1
          THEN BEEP
               LOOP
          ELSE Next=Next-1
        ENDIF
      CASE c=-80:                       ;Down
        IF Line=6
          THEN BEEP
               LOOP
          ELSE Next=Next+1
        ENDIF
      CASE c=13:                        ;Enter
        RETURN Line
      CASE c=27:                        ;Esc
        RETURN 0
      OTHERWISE:
        BEEP
        LOOP
    ENDSWITCH
    CANVAS OFF
    PAINTCANVAS
      ATTRIBUTE 79
      8+Line,52,8+Line,57
    Line=Next
  ENDWHILE
ENDPROC


;***********************************************;
; GetRptDscpt() gets the report name (e.g. "R") ;
; and description of all reports defined for    ;
; the given table (i.e. TableName).             ;
;***********************************************;
PROC GetRptDscpt(TableName)
  PRIVATE i,x1,y1,RptCount,RptName,RptDscpt,
          Maxlen,Line,Next

  x1=30
  RptCount = 0
  Line=1
  Next=1

  ARRAY RptName[15]
  RptName[1]=" "

  ARRAY RptDscpt[15]
  RptDscpt[1]=""

  CURSOR OFF
  MESSAGE "Getting report title data..."
  IF ISFILE(TableName+".R")
    THEN RptCount=RptCount+1
         RptName[RptCount]="R"
  ENDIF

  FOR i FROM 1 TO 14
    IF ISFILE(TableName+".R"+STRVAL(i))
      THEN RptCount=RptCount+1
           RptName[RptCount]=STRVAL(i)
    ENDIF
  ENDFOR

  MENU {Report} {Change}
  SELECT TableName
  FOR i FROM 1 TO RptCount
    SELECT RptName[i]
    RptDscpt[i]=MENUCHOICE()
    ESC
  ENDFOR
  MENU

  y1=INT((22-RptCount)/2)
  IF RptCount=0
    THEN Reports=False
         RptCount=1
    ELSE Reports=True
  ENDIF
  ;
  ; display report descriptions
  ;
  DscptScr(y1,x1)
  IF NOT Reports
    THEN STYLE ATTRIBUTE 112
         @y1+1,x1+2 ??"None"
         BEEP
         SLEEP 1200
         RETURN ""
  ENDIF

  WHILE True
    ;
    ; highlight current selection
    ;
    PAINTCANVAS
      ATTRIBUTE 112
      y1+Line,x1+1,y1+Line,x1+6+MaxLen
    CANVAS ON
    ;
    ; get user input
    ;
    c=GETCHAR()

    SWITCH
      CASE c=-72:                      ;Up
        IF Line=1
          THEN BEEP
               LOOP
          ELSE Next=Next-1
        ENDIF
      CASE c=-80:                      ;Down
        IF Line=RptCount
          THEN BEEP
               LOOP
          ELSE Next=Next+1
        ENDIF
      CASE c=13:                       ;Enter
        Names[2]=RptName[Line]
        RETURN
      CASE c=27:                       ;Esc
        RETURN
      OTHERWISE:
        BEEP
        LOOP
    ENDSWITCH
    CANVAS OFF
    ;
    ; clear highlight
    ;
    PAINTCANVAS
      ATTRIBUTE 32
      y1+Line,x1+1,y1+Line,x1+6+MaxLen
    Line=Next
  ENDWHILE
ENDPROC


;***********************************************;
; DscptScr() is called by GetRptDscpt() to open ;
; a window sized to the number and length of    ;
; report descriptions.                          ;
;***********************************************;
PROC DscptScr(y1,x1)
  PRIVATE TempLen,x2,y2

  MaxLen = 0
  ;
  ; find longest report description
  ;
  FOR i FROM 1 TO RptCount
    TempLen=LEN(RptDscpt[i])
    IF TempLen>MaxLen
      THEN MaxLen=TempLen
    ENDIF
  ENDFOR
  ;
  ; set minimum window width
  ;
  IF MaxLen<20
    THEN MaxLen=20
  ENDIF

  CANVAS OFF

  x2=x1+MaxLen+7
  y2=y1+RptCount+1
  ;
  ; paint shadow
  ;
  PAINTCANVAS
    ATTRIBUTE 8
    y1+1,x1+1,y2+1,x2+1

  @y1,x1 ?? CHR(218)
  PAINTCANVAS FILL CHR(196)
    y1,x1+1,y1,x2-1
  @y1,x2 ?? CHR(191)
  @y1,x1+1 ?? "AVAILABLE REPORTS"

  FOR i FROM 1 TO RptCount
    @y1+i,x1 ?? CHR(179)+FORMAT("w3,ar",RptName[i])+"  "+
                RptDscpt[i]+SPACES(MaxLen-LEN(RptDscpt[i]))+
                " "+CHR(179)
  ENDFOR

  @y2,x1 ?? CHR(192)
  PAINTCANVAS FILL CHR(196)
    y2,x1+1,y2,x2-1
  @y2,x2 ?? CHR(217)

  PAINTCANVAS
    ATTRIBUTE 32
    y1,x1,y2,x2

  CANVAS ON
ENDPROC


WRITELIB "LookUp" LookUpTab,TabLkUpScr,LookUpPntr,
                  LookUpPort,GetRptDscpt,DscptScr
RELEASE PROCS LookUpTab,TabLkUpScr,LookUpPntr,
              LookUpPort,GetRptDscpt,DscptScr
